@@ -115,7 +115,7 @@ class PrtgApi:
         Returns:
             str: XML structure of sensortree
         """
-        endpoint = 'api/table.xml'
+        endpoint = '/api/table.xml'
         params = {
             'content': 'sensortree',
             'id': group_id
